@@ -11,7 +11,7 @@ from json import load as loadjson, dump as dumpjson
 from time import ctime
 from os import path, environ, stat, name as os_name
 from tempfile import gettempdir
-from logging import DEBUG, basicConfig, info, warning, error
+from logging import DEBUG, basicConfig, info, warning, error, debug
 from subprocess import check_output
 
 import sys
@@ -19,7 +19,7 @@ import sys
 from util import ip
 from util.cache import Cache
 
-__version__ = "v2.9.6@2020-08-04T08:46:22+00:00"  # CI 时会被Tag替换
+__version__ = "v2.9.7@2020-09-11T03:24:57+00:00"  # CI 时会被Tag替换
 __description__ = "automatically update DNS records to dynamic local IP [自动更新DNS记录指向本地IP]"
 __doc__ = """
 ddns[%s]
@@ -28,7 +28,7 @@ ddns[%s]
 Copyright (c) New Future (MIT License)
 """ % (__version__)
 
-environ["DDNS_VERSION"] = "v2.9.6"
+environ["DDNS_VERSION"] = "v2.9.7"
 
 if getattr(sys, 'frozen', False):
     # https://github.com/pyinstaller/pyinstaller/wiki/Recipe-OpenSSL-Certificate
@@ -185,9 +185,11 @@ def main():
     cache = get_config('cache', True) and Cache(CACHE_FILE)
     if cache is False:
         info("Cache is disabled!")
-    elif len(cache) < 1 or get_config.time >= cache.time:
+    elif get_config.time >= cache.time:
         warning("Cache file is out of dated.")
         cache.clear()
+    elif not cache:
+        debug("Cache is empty.")
     update_ip('4', cache, dns, proxy_list)
     update_ip('6', cache, dns, proxy_list)
 
